﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Extensions.Logging;
using RemotePaging.Models;

namespace RemotePaging.Controllers
{
    public class HomeController : Controller
    {
        private readonly ILogger<HomeController> _logger;
        private List<Product> data;

        public HomeController(ILogger<HomeController> logger)
        {
            data = generateData();
            _logger = logger;
        }

        public IActionResult Index()
        {
            return View();
        }

        public IActionResult Privacy()
        {
            return View();
        }

        [ResponseCache(Duration = 0, Location = ResponseCacheLocation.None, NoStore = true)]
        public IActionResult Error()
        {
            return View(new ErrorViewModel { RequestId = Activity.Current?.Id ?? HttpContext.TraceIdentifier });
        }

        [HttpPost]
        public async Task<IActionResult> GetData()
        {

            var reader = await HttpContext.Request.BodyReader.ReadAsync();
            var buffer = reader.Buffer;
            var body = Encoding.UTF8.GetString(buffer.FirstSpan);
            var dict = Newtonsoft.Json.JsonConvert.DeserializeObject<Dictionary<string, int>>(body);

            List<Product> list = ApplyPaging(dict["page"], dict["pageSize"]);

            return Ok(new { records = list, totalRecordsCount = data.Count() });
        }

        private List<Product> generateData()
        {
            List<Product> list = new List<Product>();
            for (int i = 0; i < 1000; i++)
            {
                list.Add(new Product() { ID = i, Name = "asd" + i });
            }
            return list;
        }

        public List<Product> ApplyPaging(int page, int pageSize)
        {
            List<Product> pagedData = data.Skip(page * pageSize).Take(pageSize).ToList();
            return pagedData;
        }
    }
}
